@@ -27,6 +27,11 @@ sub tag                  { my ( $self, $n )   = @_; $n->tag }
 sub tag_attr : Attr(tag) { my ( undef, $ctx ) = @_; $ctx->n->tag }
 sub id                   { my ( $self, $n )   = @_; $n->attribute('id') }
 
+sub autoload_attribute {
+    my ( $self, $name ) = @_;
+    sub { $_[1]->n->attribute($name) }
+}
+
 sub BUILD { $_[0]->_node_type('Element') }
 
 __PACKAGE__->meta->make_immutable;
